@@ -23,6 +23,9 @@ if requirements.is_file():
 else:
     install_requires = list()
 
+atlas_url = f'mongodb+srv://{os.environ["USER"]}:' \
+      f'{os.environ["NFERX_ATLAS_PASSWORD"]}@pen.ydo6l.mongodb.net/pen?retryWrites=true&w=majority'
+
 __all__ = ['package', 'project', 'scripts', 'scripts_relative', 'readme', 'description']
 
 for global_var, global_value in os.environ.items():
