@@ -43,7 +43,7 @@ EOT
 function kali() {
   # "${1}" - force
   # "${1}" - password
-  local force password group file user error
+  local force password group file user
   while (( "$#" )); do
     case "${1}" in
       force) force="${1}" ;;
@@ -62,7 +62,7 @@ Defaults !requiretty
 %${group} ALL=(ALL) NOPASSWD:ALL
 Defaults: %${group} !logfile, !syslog
 EOT
-        if /usr/sbin/visudo -cf "${file}" > /dev/null ; then
+        if sudo /usr/sbin/visudo -cf "${file}" > /dev/null ; then
           info.sh sudoers "${file}"
         else
           error.sh sudoers 'visudo -cf' "${file}"; return 1
@@ -82,12 +82,10 @@ Defaults !requiretty
 ${user} ALL=(ALL) NOPASSWD:ALL
 Defaults: ${user} !logfile, !syslog
 EOT
-        if error="$( sudo /usr/sbin/visudo -cf "${file}" 2>&1 )"; then
+        if sudo /usr/sbin/visudo -cf "${file}" > /dev/null ; then
           info.sh sudoers "${file}"
         else
-          if ! echo "${error}" | grep "Permission denied" > /dev/null 2>&1; then
-            error.sh sudoers 'visudo -cf' "${file}"; return 1
-          fi
+          error.sh sudoers 'visudo -cf' "${file}"; return 1
         fi
       else
         error.sh sudoers tee "${file}"; return 1
